package com.xayah.materialyoufileexplorer.adapter

import android.app.Activity
import android.content.Context
import android.content.Intent
import android.view.LayoutInflater
import android.view.ViewGroup
import androidx.appcompat.app.AppCompatActivity
import androidx.appcompat.content.res.AppCompatResources
import androidx.recyclerview.widget.RecyclerView
import com.google.android.material.dialog.MaterialAlertDialogBuilder
import com.xayah.materialyoufileexplorer.ExplorerViewModel
import com.xayah.materialyoufileexplorer.R
import com.xayah.materialyoufileexplorer.databinding.ActivityExplorerBinding
import com.xayah.materialyoufileexplorer.databinding.AdapterFileBinding


class FileListAdapter(private val mContext: Context, private val model: ExplorerViewModel) :
    RecyclerView.Adapter<FileListAdapter.Holder>() {
    class Holder(val binding: AdapterFileBinding) : RecyclerView.ViewHolder(binding.root)

    private lateinit var activityBinding: ActivityExplorerBinding

    private var isFile = false

    private lateinit var activity: AppCompatActivity

    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): Holder {
        return Holder(
            AdapterFileBinding.inflate(LayoutInflater.from(mContext), parent, false)
        )
    }

    override fun onBindViewHolder(holder: Holder, position: Int) {
        val current = model.fileList[position]
        val binding = holder.binding
        binding.titleView.text = current.name
        if (current.isDir) {
            if (current.name == "..") {
                binding.iconView.background =
                    AppCompatResources.getDrawable(mContext, R.drawable.ic_round_return)
            } else {
                binding.iconView.background =
                    AppCompatResources.getDrawable(mContext, R.drawable.ic_round_folder)
            }
        } else {
            binding.iconView.background =
                AppCompatResources.getDrawable(mContext, R.drawable.ic_round_file)
        }
        binding.content.setOnClickListener {
            val dirName = binding.titleView.text

            if (current.isDir) {
                if (current.name == "..") {
                    model.removePath()
                } else {
                    model.addPath(dirName.toString())
                }
                notifyDataSetChanged()
            } else {
                if (isFile) {
                    MaterialAlertDialogBuilder(activity).setTitle(mContext.getString(R.string.tips))
                        .setMessage(mContext.getString(R.string.query_file))
                        .setNegativeButton(mContext.getString(R.string.cancel)) { _, _ -> }
                        .setPositiveButton(mContext.getString(R.string.confirm)) { _, _ ->
                            model.addPath(dirName.toString())
                            val intent = Intent().apply {
                                putExtra("path", model.getPath())
                                putExtra("isFile", isFile)
                            }
                            activity.setResult(Activity.RESULT_OK, intent)
                            activity.finish()
                        }.show()
                }
            }
        }
    }

    override fun getItemCount(): Int {
        return model.fileList.size
    }

    override fun getItemId(position: Int): Long {
        return position.toLong()
    }

    override fun getItemViewType(position: Int): Int {
        return position
    }

    fun bind(binding: ActivityExplorerBinding) {
        this.activityBinding = binding
    }

    fun init(activity: AppCompatActivity, isFile: Boolean) {
        this.activity = activity
        this.isFile = isFile
    }
}